@@ -1,3 +1,4 @@
+#include <config.h>
 #include <gtk/gtk.h>
 #include "gtk-compat.h"
 
@@ -181,7 +182,7 @@ unmarshal_callback (gpointer data)
   int ret_val = FALSE;
   GtkArg args[1];
   args[0].type = GTK_TYPE_BOOL;
-  args[0].name;
+  args[0].name = NULL;
   GTK_RETLOC_BOOL (args[0]) = &ret_val;
   cdata->marshal (NULL, cdata->func_data, 0, args);
   return ret_val;
@@ -348,6 +349,37 @@ gdk_color_parse_interp (char *spec)
 {
   /* not reentrant */
   static GdkColor color;
-  gdk_color_parse (spec, &color);
+  if (!gdk_color_parse (spec, &color))
+    return NULL;
   return &color;
 }
+
+GdkColor*
+gtk_style_get_white_interp (GtkStyle *style)
+{
+  return &style->white;
+}
+
+#ifndef HAVE_GTK_WIDGET_PEEK_COLORMAP
+GdkColormap *
+gtk_widget_peek_colormap ()
+{
+  return gtk_widget_get_default_colormap ();
+}
+#endif
+
+void
+gtk_list_append_item (GtkList *list, GtkListItem *item)
+{
+  GList *items = g_list_alloc ();
+  items->data = item;
+  gtk_list_append_items (list, items);
+}
+
+void
+gtk_list_prepend_item (GtkList *list, GtkListItem *item)
+{
+  GList *items = g_list_alloc ();
+  items->data = item;
+  gtk_list_prepend_items (list, items);
+}
