@@ -5,6 +5,8 @@ BEGIN_GNOME_DECLS
 
 typedef struct {
 	GtkWidget *notebook;
+
+	GList *props;
 } GnomePropertyConfigurator;
 
 /* This is the first parameter to the callback function */
@@ -20,6 +22,10 @@ void                      gnome_property_configurator_register (GnomePropertyCon
 							        GtkWidget *title_widget,
 								GtkWidget *content_widget,
 								int (*callback)(GnomePropertyRequest));
+
+gint                      gnome_property_configurator_request (GnomePropertyConfigurator *, GnomePropertyRequest);
+
+
 END_GNOME_DECLS
 
 #endif
