@@ -5,6 +5,10 @@
 #include "libgnomeui/gnome-colors.h"
 #include "libgnomeui/gnome-color-selector.h"
 
+BEGIN_GNOME_DECLS
+
 void gnome_init (int *argc, char ***argv);
 
+END_GNOME_DECLS
+
 #endif
