@@ -9,8 +9,6 @@
 
 #define _(String) gettext(String)
 
-#define PAD 10
-
 static GtkWidget *frame;
 static GtkWidget *monitor;
 
@@ -194,77 +192,84 @@ color_setup ()
 	GtkWidget *button2;
 	GtkWidget *radio1;
 	GtkWidget *radio2;
+	GtkWidget *vb1, *vb2;
 	GdkColor  color1, color2;
 	
-	frame = gtk_frame_new(_("Color"));
-	gtk_widget_show(frame);
+	frame = gtk_frame_new (_("Color"));
+	gtk_widget_show (frame);
 
-	table = gtk_table_new(4, 2, FALSE);
-	gtk_container_border_width(GTK_CONTAINER(table), 4);
-	gtk_table_set_row_spacing(GTK_TABLE(table), 1, 6);
-	gtk_table_set_col_spacing(GTK_TABLE(table), 0, 4);
-	gtk_container_add(GTK_CONTAINER(frame), table);
-	gtk_widget_show(table);
+	vb1= gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (vb1);
+	vb2= gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (vb2);
+
+	table = gtk_table_new (2, 2, FALSE);
+	gtk_container_border_width (GTK_CONTAINER(table), GNOME_PAD);
+	gtk_table_set_col_spacings (GTK_TABLE(table), GNOME_PAD);
+	gtk_container_add (GTK_CONTAINER(frame), table);
+	gtk_widget_show (table);
 
 	cs1 = gnome_color_selector_new((SetColorFunc) fill_monitor, NULL);
-	gdk_color_parse (gnome_config_get_string ("/Desktop/Background/color1=rgb:00/00/00"), &color1);
+	gdk_color_parse (gnome_config_get_string ("/Desktop/Background/color1=#000000"), &color1);
 	gnome_color_selector_set_color_int (cs1, color1.red, color1.green, color1.blue, 65535);
 	
-	button1 = gnome_color_selector_get_button(cs1);
-	gtk_table_attach(GTK_TABLE(table), button1, 0, 1, 0, 2, 0, 0, 0, 0);
-	gtk_widget_show(button1);
+	button1 = gnome_color_selector_get_button (cs1);
+	gtk_table_attach (GTK_TABLE(table), button1, 0, 1, 0, 1, 0, 0, 0, 0);
+	gtk_widget_show (button1);
 
-	radio1 = gtk_radio_button_new_with_label(NULL, _("Flat"));
+	radio1 = gtk_radio_button_new_with_label (NULL, _("Flat"));
 	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
 			    (GtkSignalFunc) set_background_mode,
 			    (gpointer) ((long) FALSE));
-	gtk_table_attach_defaults(GTK_TABLE(table), radio1, 1, 2, 0, 1);
-	gtk_widget_show(radio1);
+	gtk_box_pack_start (GTK_BOX (vb1), radio1, FALSE, FALSE, 0);
+	gtk_table_attach_defaults (GTK_TABLE(table), vb1, 1, 2, 0, 1);
+	gtk_widget_show (radio1);
 
-	radio1 = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(radio1)),
+	radio1 = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radio1)),
 						 _("Gradient"));
 	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
 			    (GtkSignalFunc) set_background_mode,
 			    (gpointer) ((long) TRUE));
-	gtk_table_attach_defaults(GTK_TABLE(table), radio1, 1, 2, 1, 2);
+	gtk_box_pack_start (GTK_BOX (vb1), radio1, FALSE, FALSE, 0);
 	gtk_widget_show(radio1);
 
-	cs2 = gnome_color_selector_new((SetColorFunc) fill_monitor, NULL);
-	gdk_color_parse (gnome_config_get_string ("/Desktop/Background/color2=rgb:00/00/ff"), &color2);
+	cs2 = gnome_color_selector_new ((SetColorFunc) fill_monitor, NULL);
+	gdk_color_parse (gnome_config_get_string ("/Desktop/Background/color2=#0000ff"), &color2);
 	gnome_color_selector_set_color_int (cs2, color2.red, color2.green, color2.blue, 65535);
 
 	/* fill_monitor(); */
 
-	button2 = gnome_color_selector_get_button(cs2);
-	gtk_table_attach(GTK_TABLE(table), button2, 0, 1, 2, 4, 0, 0, 0, 0);
-	gtk_widget_set_sensitive(button2, FALSE);
-	gtk_widget_show(button2);
-	gtk_signal_connect(GTK_OBJECT(radio1), "toggled",
-			   (GtkSignalFunc) radio_toggle_widget_active,
-			   button2);
+	button2 = gnome_color_selector_get_button (cs2);
+	gtk_table_attach (GTK_TABLE(table), button2, 0, 1, 1, 2, 0, 0, 0, 0);
+	gtk_widget_set_sensitive (button2, FALSE);
+	gtk_widget_show (button2);
+	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
+			    (GtkSignalFunc) radio_toggle_widget_active,
+			    button2);
 
-	radio2 = gtk_radio_button_new_with_label(NULL, _("Vertical"));
-	gtk_signal_connect(GTK_OBJECT(radio2), "toggled",
-			   (GtkSignalFunc) set_orientation,
-			   (gpointer) ((long) TRUE));
-	gtk_table_attach_defaults(GTK_TABLE(table), radio2, 1, 2, 2, 3);
-	gtk_widget_set_sensitive(radio2, FALSE);
-	gtk_widget_show(radio2);
-	gtk_signal_connect(GTK_OBJECT(radio1), "toggled",
-			   (GtkSignalFunc) radio_toggle_widget_active,
-			   radio2);
+	radio2 = gtk_radio_button_new_with_label (NULL, _("Vertical"));
+	gtk_signal_connect (GTK_OBJECT(radio2), "toggled",
+			    (GtkSignalFunc) set_orientation,
+			    (gpointer) ((long) TRUE));
+	gtk_box_pack_start (GTK_BOX (vb2), radio2, FALSE, FALSE, 0);
+	gtk_widget_set_sensitive (radio2, FALSE);
+	gtk_widget_show (radio2);
+	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
+			    (GtkSignalFunc) radio_toggle_widget_active,
+			    radio2);
 
-	radio2 = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(radio2)),
+	radio2 = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radio2)),
 						 _("Horizontal"));
-	gtk_signal_connect(GTK_OBJECT(radio2), "toggled",
-			   (GtkSignalFunc) set_orientation,
-			   (gpointer) ((long) FALSE));
-	gtk_table_attach_defaults(GTK_TABLE(table), radio2, 1, 2, 3, 4);
-	gtk_widget_set_sensitive(radio2, FALSE);
+	gtk_signal_connect (GTK_OBJECT(radio2), "toggled",
+			    (GtkSignalFunc) set_orientation,
+			    (gpointer) ((long) FALSE));
+	gtk_box_pack_start (GTK_BOX (vb2), radio2, FALSE, FALSE, 0);
+	gtk_table_attach_defaults (GTK_TABLE(table), vb2, 1, 2, 1, 2);
+	gtk_widget_set_sensitive (radio2, FALSE);
 	gtk_widget_show(radio2);
-	gtk_signal_connect(GTK_OBJECT(radio1), "toggled",
-			   (GtkSignalFunc) radio_toggle_widget_active,
-			   radio2);
+	gtk_signal_connect (GTK_OBJECT(radio1), "toggled",
+			    (GtkSignalFunc) radio_toggle_widget_active,
+			    radio2);
 	
 	return frame;
 }
@@ -279,7 +284,7 @@ wallpaper_setup ()
 	return wallp;
 }
 
-int
+static gint
 background_action (GnomePropertyRequest req)
 {
 	char buffer [60];
@@ -289,10 +294,10 @@ background_action (GnomePropertyRequest req)
 		return 0;
 
 	gnome_color_selector_get_color_int (cs1, &r, &g, &b, 255);
-	sprintf (buffer, "rgb:%d/%d/%d", r, g, b);
+	sprintf (buffer, "#%02x%02x%02x", r, g, b);
 	gnome_config_set_string ("/Desktop/Background/color1", buffer);
 	gnome_color_selector_get_color_int (cs2, &r, &g, &b, 255);
-	sprintf (buffer, "rgb:%d/%d/%d", r, g, b);
+	sprintf (buffer, "#%02x%02x%02x", r, g, b);
 	gnome_config_set_string ("/Desktop/Background/color2", buffer);
 	
 	return 1;
@@ -313,23 +318,23 @@ background_setup (GtkWidget *window)
 	vbox = gtk_vbox_new (TRUE, 0);
 
 	hbox = gtk_hbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER(hbox), 10);
+	gtk_container_border_width (GTK_CONTAINER(hbox), GNOME_PAD);
 
 	monitor = get_monitor_preview_widget (window);
 	
-	gtk_box_pack_start (GTK_BOX(hbox), monitor, FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX(hbox), monitor, FALSE, FALSE, 0);
 
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, 1, 1, 1);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 	
-	settings = gtk_hbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER(settings), 10);
-	gtk_box_pack_end (GTK_BOX (vbox), settings, 1, 1, 0);
+	settings = gtk_hbox_new (TRUE, GNOME_PAD);
+	gtk_container_border_width (GTK_CONTAINER(settings), GNOME_PAD);
+	gtk_box_pack_end (GTK_BOX (vbox), settings, TRUE, TRUE, 0);
 
 	fill = color_setup ();
-	gtk_box_pack_start (GTK_BOX (settings), fill, 1, 1, PAD);
+	gtk_box_pack_start (GTK_BOX (settings), fill, TRUE, TRUE, 0);
 	
 	wallp  = wallpaper_setup ();
-	gtk_box_pack_end (GTK_BOX (settings), wallp, 1, 1, PAD);
+	gtk_box_pack_end (GTK_BOX (settings), wallp, TRUE, TRUE, 0);
 	
 	gtk_widget_show (monitor);
 	gtk_widget_show (settings);
