@@ -14,6 +14,8 @@
 
 #define _(String) gettext(String)
 
+ConfigScreenSaver *css;
+
 struct SelectInfo {
 	ConfigScreenSaver *th;
 	ScreenSaverMode *m;
@@ -51,39 +53,57 @@ ConfigScreenSaver::setup_mode (GtkWidget *, ConfigScreenSaver *th)
 }
 
 static void
-insert_modes_to_list (gchar *n, ScreenSaverMode *m, ConfigScreenSaver *th)
+insert_modes_to_list (ScreenSaverMode *m, ConfigScreenSaver *th)
 {
 	GtkWidget *listItem;
 
-	// printf ("adding %s\n", n);
-	listItem = gtk_list_item_new_with_label (n);
+        // printf ("adding %s\n", m->name);
+	listItem = gtk_list_item_new_with_label (m->name);
 	gtk_signal_connect (GTK_OBJECT (listItem),
 			    "button_press_event",
 			    (GtkSignalFunc) ConfigScreenSaver::select_mode,
 			    (gpointer)new SelectInfo (th, m));
 	gtk_container_add (GTK_CONTAINER (th->mlist), listItem);
 	gtk_widget_show (listItem);
+
+	m->lp = gtk_list_child_position (GTK_LIST (th->mlist), listItem);
 }
 
 void
 ConfigScreenSaver::add_screensaver (ScreenSaver *ss)
 {
-	g_list_append (ssavers, (gpointer)ss);
-	g_hash_table_foreach (ss->modes, (GHFunc) insert_modes_to_list, this);
+	g_hash_table_insert (ssavers, ss->name, ss);
+	g_list_foreach (ss->modesL, (GFunc) insert_modes_to_list, this);
 }
 
 void
 ConfigScreenSaver::setup_screensavers ()
 {
-	/* xlock = new XLockMore;
-	   xlock->appendTo (GTK_LIST (mlist));
-	   xlock->setPreview (monitor,
-	   GNOME_MONITOR_WIDGET_X,
-	   GNOME_MONITOR_WIDGET_Y,
-	   GNOME_MONITOR_WIDGET_WIDTH,
-	   GNOME_MONITOR_WIDGET_HEIGHT);
-	   */
+	// add all known screensavers (ok, now we have only xlockmore :)
 	add_screensaver (new XLockMore);
+
+	/* printf ("screensaver: %s\nmode: %s\n",
+				     gnome_config_get_string ("/Desktop/"
+							      "ScreenSaver/"
+							      "screensaver=xlockmore"),
+					     gnome_config_get_string ("/Desktop/"
+								      "ScreenSaver/"
+								      "mode=blank")
+		); */
+
+	// look in config for mode
+	ScreenSaver *ss = (ScreenSaver *)
+		g_hash_table_lookup (ssavers,
+				     gnome_config_get_string ("/Desktop/"
+							      "ScreenSaver/"
+							      "screensaver=xlockmore"));
+	if (ss)
+		curMode = (ScreenSaverMode *)
+			g_hash_table_lookup (ss->modes,
+					     gnome_config_get_string ("/Desktop/"
+								      "ScreenSaver/"
+								      "mode=blank"));
+	gtk_list_select_item (GTK_LIST (mlist), curMode->lp);
 }
 
 GtkWidget *
@@ -94,23 +114,23 @@ ConfigScreenSaver::settings_frame ()
 	GtkObject *adjustment;
 	GtkWidget *vb1, *l3, *hb2, *l4, *l5;
 	
-	f  = gtk_frame_new ("Settings");
+	f  = gtk_frame_new (_("Settings"));
 
-	l1 = gtk_label_new ("Wait");
-	l2 = gtk_label_new ("min");
+	l1 = gtk_label_new (_("Wait"));
+	l2 = gtk_label_new (_("min"));
 	waitMin  = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (waitMin),
-			    gnome_config_get_string ("/Desktop/ScreenSaver/wainMin=5"));
+			    gnome_config_get_string ("/Desktop/ScreenSaver/waitMin=5"));
 
 	gtk_widget_set_usize (waitMin, 50, -1);
 	hb1 = gtk_hbox_new (FALSE, 0);
 
-	lock = gtk_check_button_new_with_label ("requires password");
+	lock = gtk_check_button_new_with_label (_("requires password"));
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (lock),
 				     gnome_config_get_int ("/Desktop/ScreenSaver/lock=1"));
 
 	vb1 = gtk_vbox_new (FALSE, 0);
-	l3 = gtk_label_new ("Priority");
+	l3 = gtk_label_new (_("Priority"));
 	gtk_misc_set_alignment (GTK_MISC (l3), 0, 0.5);
 
 	adjustment = gtk_adjustment_new (gnome_config_get_int ("/Desktop/ScreenSaver/nice=12"),
@@ -118,8 +138,8 @@ ConfigScreenSaver::settings_frame ()
 	nice = gtk_hscale_new (GTK_ADJUSTMENT (adjustment));
 	gtk_scale_set_digits (GTK_SCALE (nice), 0);
 	gtk_scale_set_draw_value (GTK_SCALE (nice), FALSE);
-	l4 = gtk_label_new ("normal");
-	l5 = gtk_label_new ("low");
+	l4 = gtk_label_new (_("normal"));
+	l5 = gtk_label_new (_("low"));
 	hb2 = gtk_hbox_new (FALSE, 0);
      
 	vbox = gtk_vbox_new (FALSE, 10);
@@ -157,9 +177,9 @@ ConfigScreenSaver::settings_frame ()
 GtkWidget *
 ConfigScreenSaver::modes_frame ()
 {
-	GtkWidget *f, *hb1, *sw, *vb1, *b1, *b2;
+	GtkWidget *f, *hb1, *vb1, *b1, *b2;
 
-	f  = gtk_frame_new ("Screen savers");
+	f  = gtk_frame_new (_("Screen savers"));
 
 	hb1 = gtk_hbox_new (FALSE, 10);
 	gtk_container_border_width (GTK_CONTAINER (hb1), 10);
@@ -171,11 +191,11 @@ ConfigScreenSaver::modes_frame ()
 	gtk_list_set_selection_mode (GTK_LIST (mlist), GTK_SELECTION_BROWSE);
 	gtk_widget_set_usize (f, 220, -1);
 	vb1 = gtk_vbox_new (FALSE, 10);
-	b1 = gtk_button_new_with_label ("Setup");
+	b1 = gtk_button_new_with_label (_("Setup"));
 	gtk_signal_connect (GTK_OBJECT (b1), "clicked",
 			    (GtkSignalFunc) setup_mode, (gpointer)this);
 
-	b2 = gtk_button_new_with_label ("Test");
+	b2 = gtk_button_new_with_label (_("Test"));
 	gtk_signal_connect (GTK_OBJECT (b2), "clicked",
 			    (GtkSignalFunc) test_mode, (gpointer)this);
 
@@ -224,14 +244,15 @@ ConfigScreenSaver::ConfigScreenSaver (GtkWidget *window)
 	GtkWidget *hbox, *bottom;
 	GtkWidget *settings, *modes;
 	
-	ssavers = g_list_alloc ();
+	ssavers = g_hash_table_new (g_hash_function_gcharp,
+				    g_hash_compare_gcharp);
 	curMode = NULL;
 	
 	vbox = gtk_vbox_new (TRUE, 0);
 	hbox = gtk_hbox_new (TRUE, 0);
-	gtk_container_border_width (GTK_CONTAINER (hbox), 10);
-	bottom = gtk_hbox_new (FALSE, 10);
-	gtk_container_border_width (GTK_CONTAINER (bottom), 10);
+	gtk_container_border_width (GTK_CONTAINER (hbox), GNOME_PAD);
+	bottom = gtk_hbox_new (FALSE, GNOME_PAD);
+	gtk_container_border_width (GTK_CONTAINER (bottom), GNOME_PAD);
 
 	monitor = get_monitor_preview_widget (window);
 	gtk_signal_connect (GTK_OBJECT (monitor), "map",
@@ -245,11 +266,11 @@ ConfigScreenSaver::ConfigScreenSaver (GtkWidget *window)
 	settings = settings_frame ();
 	modes = modes_frame ();
 
-	gtk_box_pack_start (GTK_BOX(hbox), monitor, FALSE, FALSE, 5);
-	gtk_box_pack_start (GTK_BOX(bottom), settings, FALSE, TRUE, 5);
-	gtk_box_pack_start (GTK_BOX(bottom), modes, TRUE, TRUE, 5);
+	gtk_box_pack_start (GTK_BOX(hbox), monitor, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(bottom), settings, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX(bottom), modes, TRUE, TRUE, 0);
 	gtk_box_pack_end (GTK_BOX (vbox), bottom, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 1);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
 	setup_screensavers ();
 
@@ -265,10 +286,33 @@ ConfigScreenSaver::ConfigScreenSaver (GtkWidget *window)
 GtkWidget *
 prepareConfigScreenSaver (GtkWidget *w)
 {
-	ConfigScreenSaver *css = new ConfigScreenSaver (w);
+	css = new ConfigScreenSaver (w);
 	return css->vbox;
 }
 
+static gint
+screensaver_action (GnomePropertyRequest req)
+{
+	char buffer [60];
+	int r, g, b;
+	
+	if (req != GNOME_PROPERTY_APPLY)
+		return 0;
+
+	gnome_config_set_string ("/Desktop/ScreenSaver/screensaver",
+				 css->curMode->parent->name);
+	gnome_config_set_string ("/Desktop/ScreenSaver/mode",
+				 css->curMode->name);
+	gnome_config_set_int ("/Desktop/ScreenSaver/nice",
+			      (gint)(GTK_RANGE (css->nice)->adjustment->value));
+	gnome_config_set_string ("/Desktop/ScreenSaver/lock",
+				 (GTK_TOGGLE_BUTTON (css->lock)->active)
+				 ? "true" : "false");
+	gnome_config_set_string ("/Desktop/ScreenSaver/waitMin",
+				 gtk_entry_get_text (GTK_ENTRY (css->waitMin)));
+
+	return 1;
+}
 
 extern "C" {
 void
@@ -278,6 +322,7 @@ screensaver_setup (GtkWidget *window)
 
 	sc = prepareConfigScreenSaver (window);
 
-	register_extension (gtk_label_new (_(" Screen saver ")), sc, NULL);
+	register_extension (gtk_label_new (_(" Screen saver ")),
+			    sc, screensaver_action);
 }
 }
