@@ -2,9 +2,6 @@
 -*- scheme -*-
 !#
 
-(define (gtk-widget-show-multi . list)
-  (for-each gtk-widget-show list))
-
 (define (create-itools-panel useful-options-widget
 			     extended-options-widget
 			     build-command-func)
@@ -391,7 +388,7 @@
     (gtk-widget-show notebook)
     notebook))
 
-(define (main)
+(define (internet-tools)
   (let ((window (gtk-window-new 'toplevel))
 	(vbox (gtk-vbox-new #f 0))
 	(hbox (gtk-hbox-new #f 0))
@@ -406,4 +403,4 @@
     (gtk-signal-connect quit "clicked" (lambda () (gtk-main-quit)))
     (gtk-widget-show-multi quit hbox vbox window)))
 
-(launch-gnome main)
+(launch-gnome internet-tools)
